package
Version:
v0.0.0-...-32c0887
Opens a new window with list of versions in this module.
Published: May 1, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type SimpleClient struct {
BrowserList []*Item
OSList []*Item
}
SimpleClient represents a simple implementation of the Client interface
that uses the mileusna/useragent package for user-agent parsing.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.